@@ -31,8 +31,9 @@ import org.apache.hop.core.row.value.ValueMetaNone;
 
 public class RowMetaAndData implements Cloneable {
   private IRowMeta rowMeta;
-
   private Object[] data;
+  private static final String CONST_UNKNOWN_COLUMN = "Unknown column '";
+  private static final String CONST_WRONG_VALUE_CONVERSION = "Wrong value conversion to ";
 
   public RowMetaAndData() {
     clear();
@@ -65,7 +66,7 @@ public class RowMetaAndData implements Cloneable {
     try {
       return rowMeta.getString(data);
     } catch (HopValueException e) {
-      return rowMeta.toString() + ", error presenting data: " + e.toString();
+      return rowMeta.toString() + ", error presenting data: " + e;
     }
   }
 
@@ -141,7 +142,7 @@ public class RowMetaAndData implements Cloneable {
   public long getInteger(String valueName, long def) throws HopValueException {
     int idx = rowMeta.indexOfValue(valueName);
     if (idx < 0) {
-      throw new HopValueException("Unknown column '" + valueName + "'");
+      throw new HopValueException(CONST_UNKNOWN_COLUMN + valueName + "'");
     }
     return getInteger(idx, def);
   }
@@ -157,7 +158,7 @@ public class RowMetaAndData implements Cloneable {
   public Long getInteger(String valueName) throws HopValueException {
     int idx = rowMeta.indexOfValue(valueName);
     if (idx < 0) {
-      throw new HopValueException("Unknown column '" + valueName + "'");
+      throw new HopValueException(CONST_UNKNOWN_COLUMN + valueName + "'");
     }
     return rowMeta.getInteger(data, idx);
   }
@@ -169,7 +170,7 @@ public class RowMetaAndData implements Cloneable {
   public double getNumber(String valueName, double def) throws HopValueException {
     int idx = rowMeta.indexOfValue(valueName);
     if (idx < 0) {
-      throw new HopValueException("Unknown column '" + valueName + "'");
+      throw new HopValueException(CONST_UNKNOWN_COLUMN + valueName + "'");
     }
     return getNumber(idx, def);
   }
@@ -185,7 +186,7 @@ public class RowMetaAndData implements Cloneable {
   public Date getDate(String valueName, Date def) throws HopValueException {
     int idx = rowMeta.indexOfValue(valueName);
     if (idx < 0) {
-      throw new HopValueException("Unknown column '" + valueName + "'");
+      throw new HopValueException(CONST_UNKNOWN_COLUMN + valueName + "'");
     }
     return getDate(idx, def);
   }
@@ -201,7 +202,7 @@ public class RowMetaAndData implements Cloneable {
   public BigDecimal getBigNumber(String valueName, BigDecimal def) throws HopValueException {
     int idx = rowMeta.indexOfValue(valueName);
     if (idx < 0) {
-      throw new HopValueException("Unknown column '" + valueName + "'");
+      throw new HopValueException(CONST_UNKNOWN_COLUMN + valueName + "'");
     }
     return getBigNumber(idx, def);
   }
@@ -217,7 +218,7 @@ public class RowMetaAndData implements Cloneable {
   public boolean getBoolean(String valueName, boolean def) throws HopValueException {
     int idx = rowMeta.indexOfValue(valueName);
     if (idx < 0) {
-      throw new HopValueException("Unknown column '" + valueName + "'");
+      throw new HopValueException(CONST_UNKNOWN_COLUMN + valueName + "'");
     }
     return getBoolean(idx, def);
   }
@@ -233,7 +234,7 @@ public class RowMetaAndData implements Cloneable {
   public String getString(String valueName, String def) throws HopValueException {
     int idx = rowMeta.indexOfValue(valueName);
     if (idx < 0) {
-      throw new HopValueException("Unknown column '" + valueName + "'");
+      throw new HopValueException(CONST_UNKNOWN_COLUMN + valueName + "'");
     }
     return getString(idx, def);
   }
@@ -249,7 +250,7 @@ public class RowMetaAndData implements Cloneable {
   public byte[] getBinary(String valueName, byte[] def) throws HopValueException {
     int idx = rowMeta.indexOfValue(valueName);
     if (idx < 0) {
-      throw new HopValueException("Unknown column '" + valueName + "'");
+      throw new HopValueException(CONST_UNKNOWN_COLUMN + valueName + "'");
     }
     return getBinary(idx, def);
   }
@@ -281,7 +282,7 @@ public class RowMetaAndData implements Cloneable {
   public boolean isEmptyValue(String valueName) throws HopValueException {
     int idx = rowMeta.indexOfValue(valueName);
     if (idx < 0) {
-      throw new HopValueException("Unknown column '" + valueName + "'");
+      throw new HopValueException(CONST_UNKNOWN_COLUMN + valueName + "'");
     }
 
     IValueMeta metaType = rowMeta.getValueMeta(idx);
@@ -299,13 +300,13 @@ public class RowMetaAndData implements Cloneable {
         return rowMeta.getBigNumber(data, idx) == null;
       case IValueMeta.TYPE_BINARY:
         return rowMeta.getBinary(data, idx) == null;
-      case IValueMeta.TYPE_DATE:
-      case IValueMeta.TYPE_TIMESTAMP:
+      case IValueMeta.TYPE_DATE, IValueMeta.TYPE_TIMESTAMP:
         return rowMeta.getDate(data, idx) == null;
       case IValueMeta.TYPE_INET:
         return rowMeta.getString(data, idx) == null;
+      default:
+        throw new HopValueException("Unknown source type: " + metaType.getTypeDesc());
     }
-    throw new HopValueException("Unknown source type: " + metaType.getTypeDesc());
   }
 
   /** Converts string value into specified type. Used for constant injection. */
@@ -329,7 +330,7 @@ public class RowMetaAndData implements Cloneable {
     } else if (destinationType.isEnum()) {
       return converter.string2enum(destinationType, vs);
     } else {
-      throw new RuntimeException("Wrong value conversion to " + destinationType);
+      throw new RuntimeException(CONST_WRONG_VALUE_CONVERSION + destinationType);
     }
   }
 
@@ -339,7 +340,7 @@ public class RowMetaAndData implements Cloneable {
       throws HopValueException {
     int idx = rowMeta.indexOfValue(valueName);
     if (idx < 0) {
-      throw new HopValueException("Unknown column '" + valueName + "'");
+      throw new HopValueException(CONST_UNKNOWN_COLUMN + valueName + "'");
     }
 
     IValueMeta metaType = rowMeta.getValueMeta(idx);
@@ -367,7 +368,7 @@ public class RowMetaAndData implements Cloneable {
         } else if (destinationType.isEnum()) {
           return converter.boolean2enum(destinationType, vb);
         } else {
-          throw new RuntimeException("Wrong value conversion to " + destinationType);
+          throw new HopValueException(CONST_WRONG_VALUE_CONVERSION + destinationType);
         }
       case IValueMeta.TYPE_INTEGER:
         Long vi = rowMeta.getInteger(data, idx);
@@ -388,7 +389,7 @@ public class RowMetaAndData implements Cloneable {
         } else if (destinationType.isEnum()) {
           return converter.integer2enum(destinationType, vi);
         } else {
-          throw new RuntimeException("Wrong value conversion to " + destinationType);
+          throw new HopValueException(CONST_WRONG_VALUE_CONVERSION + destinationType);
         }
       case IValueMeta.TYPE_NUMBER:
         Double vn = rowMeta.getNumber(data, idx);
@@ -409,12 +410,12 @@ public class RowMetaAndData implements Cloneable {
         } else if (destinationType.isEnum()) {
           return converter.number2enum(destinationType, vn);
         } else {
-          throw new RuntimeException("Wrong value conversion to " + destinationType);
+          throw new HopValueException(CONST_WRONG_VALUE_CONVERSION + destinationType);
         }
+      default:
+        throw new HopValueException(
+            "Unknown conversion from " + metaType.getTypeDesc() + " into " + destinationType);
     }
-
-    throw new HopValueException(
-        "Unknown conversion from " + metaType.getTypeDesc() + " into " + destinationType);
   }
 
   public void removeValue(String valueName) throws HopValueException {
