@@ -54,7 +54,7 @@ import org.w3c.dom.Document;
 import org.w3c.dom.Node;
 
 public abstract class BasePluginType<T extends Annotation> implements IPluginType<T> {
-  protected static Class<?> classFromResourcesPackage = BasePluginType.class; // For Translator
+  protected static Class<?> classFromResourcesPackage = BasePluginType.class;
 
   protected final PluginRegistry registry;
 
@@ -62,11 +62,11 @@ public abstract class BasePluginType<T extends Annotation> implements IPluginTyp
 
   private String name;
 
-  private LogChannel log;
+  private final LogChannel log;
 
-  private Map<Class<?>, String> objectTypes = new HashMap<>();
+  private final Map<Class<?>, String> objectTypes = new HashMap<>();
 
-  private Class<T> pluginClass;
+  private final Class<T> pluginClass;
 
   private List<String> extraLibraryFolders;
 
@@ -546,11 +546,13 @@ public abstract class BasePluginType<T extends Annotation> implements IPluginTyp
     return false;
   }
 
-  protected boolean extractincludeJdbcDrivers(T annotation) {
+  protected boolean extractIncludeJdbcDrivers(T annotation) {
     return false;
   }
 
-  protected void addExtraClasses(Map<Class<?>, String> classMap, Class<?> clazz, T annotation) {}
+  protected void addExtraClasses(Map<Class<?>, String> classMap, Class<?> clazz, T annotation) {
+    // Do nothing
+  }
 
   protected String extractDocumentationUrl(T annotation) {
     return null;
@@ -639,7 +641,7 @@ public abstract class BasePluginType<T extends Annotation> implements IPluginTyp
     String suggestion = getTranslation(extractSuggestion(annotation), packageName, clazz);
     String classLoaderGroup = extractClassLoaderGroup(annotation);
     String[] keywords = getTranslations(extractKeywords(annotation), packageName, clazz);
-    boolean includeJdbcDrivers = extractincludeJdbcDrivers(annotation);
+    boolean includeJdbcDrivers = extractIncludeJdbcDrivers(annotation);
 
     Map<Class<?>, String> classMap = new HashMap<>();
 
