@@ -18,6 +18,7 @@
 package org.apache.hop.core.row;
 
 import com.fasterxml.jackson.annotation.JsonIgnore;
+import com.fasterxml.jackson.databind.JsonNode;
 import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
 import java.io.DataInputStream;
 import java.io.DataOutputStream;
@@ -32,6 +33,7 @@ import java.text.SimpleDateFormat;
 import java.util.Date;
 import java.util.Locale;
 import java.util.TimeZone;
+import lombok.Getter;
 import org.apache.hop.core.Const;
 import org.apache.hop.core.database.DatabaseMeta;
 import org.apache.hop.core.database.IDatabase;
@@ -111,6 +113,12 @@ import org.w3c.dom.Node;
  * <td>java.lang.byte[</td>
  * <td>An array of bytes that contain any type of binary data.</td>
  * </tr>
+ * <tr>
+ * <td>Json</td>
+ * <td>TYPE_JSON</td>
+ * <td>com.fasterxml.jackson.databind.JsonNode</td>
+ * <td>A native Json object.</td>
+ * </tr>
  * </Table>
  *
  * <p><b>Storage Types</b>
@@ -185,6 +193,9 @@ public interface IValueMeta extends Cloneable {
   /** Value type indicating that the value contains an Internet address */
   int TYPE_INET = 10;
 
+  /** Value type indicating that the value contains a native JSON object */
+  int TYPE_JSON = 11;
+
   /** Value type indicating that the value contains an Avro Record */
   int TYPE_AVRO = 20;
 
@@ -202,6 +213,7 @@ public interface IValueMeta extends Cloneable {
         "Binary",
         "Timestamp",
         "Internet Address",
+        "Json"
       };
 
   /** The storage type is the same as the indicated value type */
@@ -269,9 +281,27 @@ public interface IValueMeta extends Cloneable {
     LEFT("left", BaseMessages.getString(PKG, "ValueMeta.TrimType.Left"), TRIM_TYPE_LEFT),
     RIGHT("right", BaseMessages.getString(PKG, "ValueMeta.TrimType.Right"), TRIM_TYPE_RIGHT),
     BOTH("both", BaseMessages.getString(PKG, "ValueMeta.TrimType.Both"), TRIM_TYPE_BOTH);
-    private final String code;
-    private final String description;
-    private final int type;
+
+    /**
+     * -- GETTER -- Gets code
+     *
+     * @return value of code
+     */
+    @Getter private final String code;
+
+    /**
+     * -- GETTER -- Gets description
+     *
+     * @return value of description
+     */
+    @Getter private final String description;
+
+    /**
+     * -- GETTER -- Gets type
+     *
+     * @return value of type
+     */
+    @Getter private final int type;
 
     TrimType(String code, String description, int type) {
       this.code = code;
@@ -279,6 +309,12 @@ public interface IValueMeta extends Cloneable {
       this.type = type;
     }
 
+    /** The Rounding type codes */
+    @Getter
+    public static final String[] roundingTypeCode = {
+      "unnecessary", "ceiling", "down", "floor", "half_down", "half_even", "half_up", "up"
+    };
+
     public static String[] getDescriptions() {
       return IEnumHasCodeAndDescription.getDescriptions(TrimType.class);
     }
@@ -299,33 +335,6 @@ public interface IValueMeta extends Cloneable {
       }
       return NONE;
     }
-
-    /**
-     * Gets code
-     *
-     * @return value of code
-     */
-    public String getCode() {
-      return code;
-    }
-
-    /**
-     * Gets description
-     *
-     * @return value of description
-     */
-    public String getDescription() {
-      return description;
-    }
-
-    /**
-     * Gets type
-     *
-     * @return value of type
-     */
-    public int getType() {
-      return type;
-    }
   }
 
   /** Default integer length for hardcoded metadata integers */
@@ -454,6 +463,20 @@ public interface IValueMeta extends Cloneable {
    */
   void setTrimType(int trimType);
 
+  /**
+   * Gets the rounding type.
+   *
+   * @return the rounding type
+   */
+  String getRoundingType();
+
+  /**
+   * Sets the rounding type.
+   *
+   * @param roundingType the new rounding type
+   */
+  void setRoundingType(String roundingType);
+
   /**
    * Gets the index.
    *
@@ -893,6 +916,9 @@ public interface IValueMeta extends Cloneable {
   /** Convert the supplied data to a Boolean */
   Boolean getBoolean(Object object) throws HopValueException;
 
+  /** Convert the supplied data to a Json */
+  JsonNode getJson(Object object) throws HopValueException;
+
   /** Convert the supplied data to binary data */
   byte[] getBinary(Object object) throws HopValueException;
 
