@@ -59,6 +59,9 @@ public class ValueMetaTimestamp extends ValueMetaDate {
     super(name, IValueMeta.TYPE_TIMESTAMP);
   }
 
+  private static final String CONST_SPECIFIED = " specified.";
+  private static final String CONST_UNKNOWN_TYPE = " : Unknown storage type ";
+
   @Override
   public boolean isDate() {
     return true;
@@ -66,11 +69,7 @@ public class ValueMetaTimestamp extends ValueMetaDate {
 
   @Override
   public Date getDate(Object object) throws HopValueException {
-    Timestamp timestamp = getTimestamp(object);
-    if (timestamp == null) {
-      return null;
-    }
-    return timestamp;
+    return getTimestamp(object);
   }
 
   @Override
@@ -99,11 +98,9 @@ public class ValueMetaTimestamp extends ValueMetaDate {
     if (timestamp == null) {
       return null;
     }
-    BigDecimal nanos =
-        BigDecimal.valueOf(timestamp.getTime())
-            .multiply(BigDecimal.valueOf(1000000000L))
-            .add(BigDecimal.valueOf(timestamp.getNanos()));
-    return nanos;
+    return BigDecimal.valueOf(timestamp.getTime())
+        .multiply(BigDecimal.valueOf(1000000000L))
+        .add(BigDecimal.valueOf(timestamp.getNanos()));
   }
 
   @Override
@@ -131,8 +128,7 @@ public class ValueMetaTimestamp extends ValueMetaDate {
           case STORAGE_TYPE_INDEXED:
             return (Timestamp) index[((Integer) object).intValue()];
           default:
-            throw new HopValueException(
-                toString() + " : Unknown storage type " + storageType + " specified.");
+            throw new HopValueException(this + CONST_UNKNOWN_TYPE + storageType + CONST_SPECIFIED);
         }
       case TYPE_STRING:
         switch (storageType) {
@@ -144,8 +140,7 @@ public class ValueMetaTimestamp extends ValueMetaDate {
           case STORAGE_TYPE_INDEXED:
             return convertStringToTimestamp((String) index[((Integer) object).intValue()]);
           default:
-            throw new HopValueException(
-                toString() + " : Unknown storage type " + storageType + " specified.");
+            throw new HopValueException(this + CONST_UNKNOWN_TYPE + storageType + CONST_SPECIFIED);
         }
       case TYPE_NUMBER:
         switch (storageType) {
@@ -157,8 +152,7 @@ public class ValueMetaTimestamp extends ValueMetaDate {
           case STORAGE_TYPE_INDEXED:
             return convertNumberToTimestamp((Double) index[((Integer) object).intValue()]);
           default:
-            throw new HopValueException(
-                toString() + " : Unknown storage type " + storageType + " specified.");
+            throw new HopValueException(this + CONST_UNKNOWN_TYPE + storageType + CONST_SPECIFIED);
         }
       case TYPE_INTEGER:
         switch (storageType) {
@@ -170,8 +164,7 @@ public class ValueMetaTimestamp extends ValueMetaDate {
           case STORAGE_TYPE_INDEXED:
             return convertIntegerToTimestamp((Long) index[((Integer) object).intValue()]);
           default:
-            throw new HopValueException(
-                toString() + " : Unknown storage type " + storageType + " specified.");
+            throw new HopValueException(this + CONST_UNKNOWN_TYPE + storageType + CONST_SPECIFIED);
         }
       case TYPE_BIGNUMBER:
         switch (storageType) {
@@ -183,21 +176,20 @@ public class ValueMetaTimestamp extends ValueMetaDate {
           case STORAGE_TYPE_INDEXED:
             return convertBigNumberToTimestamp((BigDecimal) index[((Integer) object).intValue()]);
           default:
-            throw new HopValueException(
-                toString() + " : Unknown storage type " + storageType + " specified.");
+            throw new HopValueException(this + CONST_UNKNOWN_TYPE + storageType + CONST_SPECIFIED);
         }
       case TYPE_BOOLEAN:
         throw new HopValueException(
-            toString() + " : I don't know how to convert a boolean to a timestamp.");
+            this + " : I don't know how to convert a boolean to a timestamp.");
       case TYPE_BINARY:
         throw new HopValueException(
-            toString() + " : I don't know how to convert a binary value to timestamp.");
+            this + " : I don't know how to convert a binary value to timestamp.");
       case TYPE_SERIALIZABLE:
         throw new HopValueException(
-            toString() + " : I don't know how to convert a serializable value to timestamp.");
+            this + " : I don't know how to convert a serializable value to timestamp.");
 
       default:
-        throw new HopValueException(toString() + " : Unknown type " + type + " specified.");
+        throw new HopValueException(this + " : Unknown type " + type + CONST_SPECIFIED);
     }
   }
 
@@ -270,7 +262,7 @@ public class ValueMetaTimestamp extends ValueMetaDate {
         returnValue = (Timestamp) getDateFormat().parse(string);
       } catch (ParseException ex) {
         throw new HopValueException(
-            toString()
+            this
                 + " : couldn't convert string ["
                 + string
                 + "] to a timestamp, expecting format [yyyy-mm-dd hh:mm:ss.ffffff]",
@@ -280,8 +272,7 @@ public class ValueMetaTimestamp extends ValueMetaDate {
     return returnValue;
   }
 
-  protected synchronized String convertTimestampToString(Timestamp timestamp)
-      throws HopValueException {
+  protected synchronized String convertTimestampToString(Timestamp timestamp) {
 
     if (timestamp == null) {
       return null;
@@ -329,14 +320,13 @@ public class ValueMetaTimestamp extends ValueMetaDate {
     // See if we need to convert a null value into a String
     // For example, we might want to convert null into "Empty".
     //
-    if (!Utils.isEmpty(ifNull)) {
+    if (!Utils.isEmpty(ifNull)
+        && (Utils.isEmpty(pol)
+            || pol.equalsIgnoreCase(Const.rightPad(new StringBuilder(nullValue), pol.length())))) {
       // Note that you can't pull the pad method up here as a nullComp variable
       // because you could get an NPE since you haven't checked isEmpty(pol)
       // yet!
-      if (Utils.isEmpty(pol)
-          || pol.equalsIgnoreCase(Const.rightPad(new StringBuilder(nullValue), pol.length()))) {
-        pol = ifNull;
-      }
+      pol = ifNull;
     }
 
     // See if the polled value is empty
@@ -404,13 +394,13 @@ public class ValueMetaTimestamp extends ValueMetaDate {
     return convertData(convertMeta, pol);
   }
 
-  public Timestamp convertDateToTimestamp(Date date) throws HopValueException {
+  public Timestamp convertDateToTimestamp(Date date) {
     if (date == null) {
       return null;
     }
     Timestamp result = null;
-    if (date instanceof Timestamp) {
-      result = (Timestamp) date;
+    if (date instanceof Timestamp timestamp) {
+      result = timestamp;
     } else {
       result = new Timestamp(date.getTime());
     }
@@ -583,8 +573,7 @@ public class ValueMetaTimestamp extends ValueMetaDate {
       case STORAGE_TYPE_INDEXED:
         return convertStringToBinaryString(getString(index[((Integer) object).intValue()]));
       default:
-        throw new HopValueException(
-            toString() + " : Unknown storage type " + storageType + " specified.");
+        throw new HopValueException(this + CONST_UNKNOWN_TYPE + storageType + CONST_SPECIFIED);
     }
   }
 
@@ -619,12 +608,12 @@ public class ValueMetaTimestamp extends ValueMetaDate {
             break;
 
           default:
-            throw new HopFileException(toString() + " : Unknown storage type " + getStorageType());
+            throw new HopFileException(this + CONST_UNKNOWN_TYPE + getStorageType());
         }
       }
     } catch (ClassCastException e) {
       throw new RuntimeException(
-          toString()
+          this
               + " : There was a data type error: the data type of "
               + object.getClass().getName()
               + " object ["
@@ -634,23 +623,13 @@ public class ValueMetaTimestamp extends ValueMetaDate {
               + "]");
     } catch (IOException e) {
       throw new HopFileException(
-          toString() + " : Unable to write value timestamp data to output stream", e);
-    } catch (HopValueException e) {
-      throw new RuntimeException(
-          toString()
-              + " : There was a data type error: the data type of "
-              + object.getClass().getName()
-              + " object ["
-              + object
-              + "] does not correspond to value meta ["
-              + toStringMeta()
-              + "]");
+          this + " : Unable to write value timestamp data to output stream", e);
     }
   }
 
   @Override
   public Object readData(DataInputStream inputStream)
-      throws HopFileException, HopEofException, SocketTimeoutException {
+      throws HopFileException, SocketTimeoutException {
     try {
       // Is the value NULL?
       if (inputStream.readBoolean()) {
@@ -673,7 +652,7 @@ public class ValueMetaTimestamp extends ValueMetaDate {
           return readSmallInteger(inputStream); // just an index: 4-bytes should be enough.
 
         default:
-          throw new HopFileException(toString() + " : Unknown storage type " + getStorageType());
+          throw new HopFileException(this + CONST_UNKNOWN_TYPE + getStorageType());
       }
     } catch (EOFException e) {
       throw new HopEofException(e);
@@ -681,7 +660,7 @@ public class ValueMetaTimestamp extends ValueMetaDate {
       throw e;
     } catch (IOException e) {
       throw new HopFileException(
-          toString() + " : Unable to read value timestamp data from input stream", e);
+          this + " : Unable to read value timestamp data from input stream", e);
     }
   }
 
