@@ -26,6 +26,7 @@ import java.io.OutputStream;
 import java.util.ArrayList;
 import java.util.Comparator;
 import java.util.List;
+import java.util.Map;
 import java.util.UUID;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
 import org.apache.commons.lang.StringUtils;
@@ -39,22 +40,25 @@ import org.apache.commons.vfs2.impl.DefaultFileReplicator;
 import org.apache.commons.vfs2.impl.DefaultFileSystemManager;
 import org.apache.commons.vfs2.impl.FileContentInfoFilenameFactory;
 import org.apache.commons.vfs2.impl.StandardFileSystemManager;
+import org.apache.commons.vfs2.provider.FileProvider;
 import org.apache.commons.vfs2.provider.local.LocalFile;
 import org.apache.hop.core.Const;
 import org.apache.hop.core.exception.HopException;
 import org.apache.hop.core.exception.HopFileException;
 import org.apache.hop.core.plugins.IPlugin;
 import org.apache.hop.core.plugins.PluginRegistry;
+import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.core.vfs.plugin.IVfs;
 import org.apache.hop.core.vfs.plugin.VfsPluginType;
 import org.apache.hop.i18n.BaseMessages;
 
 public class HopVfs {
-  private static final Class<?> PKG = HopVfs.class; // For Translator
+  private static final Class<?> PKG = HopVfs.class;
 
   public static final String TEMP_DIR = System.getProperty("java.io.tmpdir");
 
   private static DefaultFileSystemManager fsm;
+  private static DefaultFileSystemManager extendedFsm;
 
   private static final ReentrantReadWriteLock lock = new ReentrantReadWriteLock();
 
@@ -64,6 +68,7 @@ public class HopVfs {
       if (fsm == null) {
         try {
           fsm = createFileSystemManager();
+          fsm.init();
         } catch (Exception e) {
           throw new RuntimeException("Error initializing file system manager : ", e);
         }
@@ -74,6 +79,47 @@ public class HopVfs {
     }
   }
 
+  public static DefaultFileSystemManager getFileSystemManager(IVariables variables) {
+    lock.readLock().lock();
+    try {
+      if (extendedFsm == null) {
+        try {
+          extendedFsm = createFileSystemManager();
+          // Here are extra VFS plugins to register
+          //
+          PluginRegistry registry = PluginRegistry.getInstance();
+          List<IPlugin> plugins = registry.getPlugins(VfsPluginType.class);
+          for (IPlugin plugin : plugins) {
+            IVfs iVfs = registry.loadClass(plugin, IVfs.class);
+            try {
+              Map<String, FileProvider> fileProviderMap = iVfs.getProviders(variables);
+              if (fileProviderMap != null) {
+                for (Map.Entry<String, FileProvider> entry : fileProviderMap.entrySet()) {
+                  extendedFsm.addProvider(entry.getKey(), entry.getValue());
+                }
+              }
+            } catch (Exception e) {
+              throw new HopException(
+                  "Error registering provider for VFS plugin "
+                      + plugin.getIds()[0]
+                      + " : "
+                      + plugin.getName()
+                      + " : ",
+                  e);
+            }
+          }
+
+          extendedFsm.init();
+        } catch (Exception e) {
+          throw new RuntimeException("Error initializing file system manager : ", e);
+        }
+      }
+      return extendedFsm;
+    } finally {
+      lock.readLock().unlock();
+    }
+  }
+
   /**
    * Make sure to close when done using!
    *
@@ -90,8 +136,8 @@ public class HopVfs {
       fsm.addProvider("zip", new org.apache.commons.vfs2.provider.zip.ZipFileProvider());
       fsm.addProvider("gz", new org.apache.commons.vfs2.provider.gzip.GzipFileProvider());
       fsm.addProvider("jar", new org.apache.commons.vfs2.provider.jar.JarFileProvider());
-      fsm.addProvider("http", new org.apache.commons.vfs2.provider.http.HttpFileProvider());
-      fsm.addProvider("https", new org.apache.commons.vfs2.provider.https.HttpsFileProvider());
+      fsm.addProvider("http", new org.apache.commons.vfs2.provider.http5.Http5FileProvider());
+      fsm.addProvider("https", new org.apache.commons.vfs2.provider.http5s.Http5sFileProvider());
       fsm.addProvider("ftp", new org.apache.commons.vfs2.provider.ftp.FtpFileProvider());
       fsm.addProvider("ftps", new org.apache.commons.vfs2.provider.ftps.FtpsFileProvider());
       fsm.addProvider("sftp", new org.apache.commons.vfs2.provider.sftp.SftpFileProvider());
@@ -141,15 +187,61 @@ public class HopVfs {
               e);
         }
       }
-
-      fsm.init();
-
       return fsm;
     } catch (Exception e) {
       throw new HopException("Error creating file system manager", e);
     }
   }
 
+  public static synchronized FileObject getFileObject(String vfsFilename, IVariables variables)
+      throws HopFileException {
+    lock.readLock().lock();
+    try {
+      DefaultFileSystemManager fsManager = getFileSystemManager(variables);
+
+      try {
+        // We have one problem with VFS: if the file is in a subdirectory of the current one:
+        // somedir/somefile
+        // In that case, VFS doesn't parse the file correctly.
+        // We need to put file: in front of it to make it work.
+        // However, how are we going to verify this?
+        //
+        // We are going to see if the filename starts with one of the known protocols like file:
+        // zip: ram: smb: jar: etc.
+        // If not, we are going to assume it's a file.
+        //
+        boolean relativeFilename = true;
+        String[] initialSchemes = fsManager.getSchemes();
+
+        relativeFilename = checkForScheme(initialSchemes, relativeFilename, vfsFilename);
+
+        String filename;
+        if (vfsFilename.startsWith("\\\\")) {
+          File file = new File(vfsFilename);
+          filename = file.toURI().toString();
+        } else {
+          if (relativeFilename) {
+            File file = new File(vfsFilename);
+            filename = file.getAbsolutePath();
+          } else {
+            filename = vfsFilename;
+          }
+        }
+
+        return fsManager.resolveFile(filename);
+      } catch (Exception e) {
+        throw new HopFileException(
+            "Unable to get VFS File object for filename '"
+                + cleanseFilename(vfsFilename)
+                + "' : "
+                + e.getMessage(),
+            e);
+      }
+    } finally {
+      lock.readLock().unlock();
+    }
+  }
+
   public static synchronized FileObject getFileObject(String vfsFilename) throws HopFileException {
     lock.readLock().lock();
     try {
@@ -225,7 +317,7 @@ public class HopVfs {
    * @param vfsFilename the filename or URL to read from
    * @param charSetName the character set of the string (UTF-8, ISO8859-1, etc)
    * @return The content of the file as a String
-   * @throws IOException
+   * @throws org.apache.hop.core.exception.HopFileException
    */
   public static String getTextFileContent(String vfsFilename, String charSetName)
       throws HopFileException {
@@ -265,6 +357,25 @@ public class HopVfs {
     }
   }
 
+  public static boolean fileExists(String vfsFilename, IVariables variables)
+      throws HopFileException {
+    FileObject fileObject = null;
+    try {
+      fileObject = getFileObject(vfsFilename, variables);
+      return fileObject.exists();
+    } catch (IOException e) {
+      throw new HopFileException(e);
+    } finally {
+      if (fileObject != null) {
+        try {
+          fileObject.close();
+        } catch (Exception e) {
+          /* Ignore */
+        }
+      }
+    }
+  }
+
   public static InputStream getInputStream(FileObject fileObject) throws FileSystemException {
     FileContent content = fileObject.getContent();
     return content.getInputStream();
@@ -280,6 +391,17 @@ public class HopVfs {
     }
   }
 
+  public static InputStream getInputStream(String vfsFilename, IVariables variables)
+      throws HopFileException {
+    try {
+      FileObject fileObject = getFileObject(vfsFilename, variables);
+
+      return getInputStream(fileObject);
+    } catch (IOException e) {
+      throw new HopFileException(e);
+    }
+  }
+
   public static OutputStream getOutputStream(FileObject fileObject, boolean append)
       throws IOException {
     FileObject parent = fileObject.getParent();
@@ -317,6 +439,16 @@ public class HopVfs {
     }
   }
 
+  public static OutputStream getOutputStream(
+      String vfsFilename, boolean append, IVariables variables) throws HopFileException {
+    try {
+      FileObject fileObject = getFileObject(vfsFilename, variables);
+      return getOutputStream(fileObject, append);
+    } catch (IOException e) {
+      throw new HopFileException(e);
+    }
+  }
+
   public static OutputStream getOutputStream(String vfsFilename, boolean append)
       throws HopFileException {
     try {
@@ -363,6 +495,21 @@ public class HopVfs {
     return friendlyName;
   }
 
+  public static String getFriendlyURI(String filename, IVariables variables) {
+    if (filename == null) {
+      return null;
+    }
+    String friendlyName;
+    try {
+      friendlyName = getFriendlyURI(HopVfs.getFileObject(filename, variables));
+    } catch (Exception e) {
+      // unable to get a friendly name from VFS object.
+      // Cleanse name of pwd before returning
+      friendlyName = cleanseFilename(filename);
+    }
+    return friendlyName;
+  }
+
   public static String getFriendlyURI(FileObject fileObject) {
     return fileObject.getName().getFriendlyURI();
   }
@@ -418,6 +565,46 @@ public class HopVfs {
     }
   }
 
+  /**
+   * @param prefix - file name
+   * @param suffix - file extension
+   * @param directory - directory where file will be created
+   * @return FileObject
+   * @throws HopFileException
+   */
+  public static synchronized FileObject createTempFile(
+      String prefix, String suffix, String directory, IVariables variables)
+      throws HopFileException {
+    try {
+      FileObject fileObject;
+      do {
+        // Temporary files are always stored locally.
+        // No other schemes besides file:// make sense
+        //
+        String baseUrl;
+        if (directory.contains("://")) {
+          baseUrl = directory;
+        } else {
+          File directoryFile = new File(directory);
+          baseUrl = "file://" + directoryFile.getAbsolutePath();
+        }
+
+        // Build temporary file name using UUID to ensure uniqueness. Old mechanism would fail using
+        // Sort Rows (for example)
+        // when there multiple nodes with multiple JVMs on each node. In this case, the temp file
+        // names would end up being
+        // duplicated which would cause the sort to fail.
+        //
+        String filename = baseUrl + "/" + prefix + "_" + UUID.randomUUID() + suffix;
+
+        fileObject = getFileObject(filename, variables);
+      } while (fileObject.exists());
+      return fileObject;
+    } catch (IOException e) {
+      throw new HopFileException(e);
+    }
+  }
+
   public static Comparator<FileObject> getComparator() {
     return (o1, o2) -> {
       String filename1 = getFilename(o1);
@@ -433,11 +620,11 @@ public class HopVfs {
    * @param vfsFileName
    * @return boolean
    */
-  public static boolean startsWithScheme(String vfsFileName) {
+  public static boolean startsWithScheme(String vfsFileName, IVariables variables) {
     lock.readLock().lock();
     try {
 
-      DefaultFileSystemManager fsManager = getFileSystemManager();
+      DefaultFileSystemManager fsManager = getFileSystemManager(variables);
 
       boolean found = false;
       String[] schemes = fsManager.getSchemes();
@@ -496,6 +683,11 @@ public class HopVfs {
       fsm.close();
       fsm = null;
     }
+    if (extendedFsm != null) {
+      extendedFsm.freeUnusedResources();
+      extendedFsm.close();
+      extendedFsm = null;
+    }
   }
 
   public enum Suffix {
