@@ -20,10 +20,9 @@ package org.apache.hop.core.vfs;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 
-import java.io.IOException;
 import java.io.OutputStream;
 import org.apache.commons.vfs2.FileObject;
-import org.apache.hop.core.exception.HopFileException;
+import org.apache.hop.core.variables.Variables;
 import org.junit.Test;
 
 public class HopVfsTest {
@@ -36,15 +35,15 @@ public class HopVfsTest {
   public void testStartsWithScheme() {
     String fileName =
         "zip:file:///SavedLinkedres.zip!Calculate median and percentiles using the group by transforms.hpl";
-    assertTrue(HopVfs.startsWithScheme(fileName));
+    assertTrue(HopVfs.startsWithScheme(fileName, new Variables()));
 
     fileName =
         "SavedLinkedres.zip!Calculate median and percentiles using the group by transforms.hpl";
-    assertFalse(HopVfs.startsWithScheme(fileName));
+    assertFalse(HopVfs.startsWithScheme(fileName, new Variables()));
   }
 
   @Test
-  public void testCheckForSchemeSuccess() throws HopFileException, IOException {
+  public void testCheckForSchemeSuccess() {
     String[] schemes = {"hdfs"};
     String vfsFilename = "hdfs://company.com:8020/tmp/acltest/";
 
@@ -53,7 +52,7 @@ public class HopVfsTest {
   }
 
   @Test
-  public void testCheckForSchemeFail() throws HopFileException, IOException {
+  public void testCheckForSchemeFail() {
     String[] schemes = {"file"};
     String vfsFilename = "hdfs://company.com:8020/tmp/acltest/";
 
