@@ -96,8 +96,8 @@ public class BeanLevelInfo<Meta extends Object> {
     while (type != null) {
       Class<Meta> clazz;
       ParameterizedType pt;
-      if (type instanceof ParameterizedType) {
-        pt = (ParameterizedType) type;
+      if (type instanceof ParameterizedType parameterizedType) {
+        pt = parameterizedType;
         clazz = (Class<Meta>) pt.getRawType();
       } else {
         pt = null;
@@ -162,9 +162,8 @@ public class BeanLevelInfo<Meta extends Object> {
       if (f.getType().isArray()) {
         Type ff = f.getGenericType();
         leaf.dim = DIMENSION.ARRAY;
-        if (ff instanceof GenericArrayType) {
-          GenericArrayType ffg = (GenericArrayType) ff;
-          t = resolveGenericType(ffg.getGenericComponentType(), genericsInfo);
+        if (ff instanceof GenericArrayType genericArrayType) {
+          t = resolveGenericType(genericArrayType.getGenericComponentType(), genericsInfo);
         } else {
           t = f.getType().getComponentType();
         }
@@ -181,9 +180,8 @@ public class BeanLevelInfo<Meta extends Object> {
         leaf.dim = DIMENSION.NONE;
         t = resolveGenericType(f.getGenericType(), genericsInfo);
       }
-      if (t instanceof ParameterizedType) {
-        ParameterizedType pt = (ParameterizedType) t;
-        leaf.leafClass = (Class<?>) pt.getRawType();
+      if (t instanceof ParameterizedType parameterizedType) {
+        leaf.leafClass = (Class<?>) parameterizedType.getRawType();
       } else {
         leaf.leafClass = (Class<?>) t;
       }
