@@ -50,6 +50,7 @@ import org.apache.hop.core.parameters.INamedParameters;
 import org.apache.hop.core.parameters.NamedParameters;
 import org.apache.hop.core.parameters.UnknownParamException;
 import org.apache.hop.core.row.RowBuffer;
+import org.apache.hop.core.util.ExecutorUtil;
 import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.core.variables.VariableRegistry;
@@ -515,19 +516,25 @@ public class RemotePipelineEngine extends Variables implements IPipelineEngine<P
         for (TransformStatus transformStatus : pipelineStatus.getTransformStatusList()) {
           EngineComponent component =
               new EngineComponent(transformStatus.getTransformName(), transformStatus.getCopy());
-          component.setErrors(transformStatus.getErrors());
           status =
               ComponentExecutionStatus.getStatusFromDescription(
                   transformStatus.getStatusDescription());
-          statusDescription = status.getDescription();
           boolean running = status == ComponentExecutionStatus.STATUS_RUNNING;
-          component.setRunning(running);
           boolean halted =
               status == ComponentExecutionStatus.STATUS_HALTED
                   || status == ComponentExecutionStatus.STATUS_HALTING;
           if (halted) {
             hasHaltedComponents = true;
           }
+
+          // Set the pipeline engine component state
+          component.setErrors(transformStatus.getErrors());
+          component.setStatus(status);
+          component.setRunning(running);
+          component.setStopped(status == ComponentExecutionStatus.STATUS_STOPPED);
+          component.setLogText(transformStatus.getLogText());
+
+          // Set the pipeline engine component metrics
           engineMetrics.setComponentStatus(component, transformStatus.getStatusDescription());
           engineMetrics.setComponentRunning(component, running);
           engineMetrics.setComponentMetric(
@@ -552,6 +559,7 @@ public class RemotePipelineEngine extends Variables implements IPipelineEngine<P
           engineMetrics.getComponents().add(component);
         }
 
+        statusDescription = pipelineStatus.getStatusDescription();
         running = pipelineStatus.isRunning();
         finished = pipelineStatus.isFinished();
         stopped = pipelineStatus.isStopped();
@@ -573,7 +581,7 @@ public class RemotePipelineEngine extends Variables implements IPipelineEngine<P
         //
         if (finished) {
           firePipelineExecutionFinishedListeners();
-          refreshTimer.cancel();
+          ExecutorUtil.cleanup(refreshTimer);
           logChannel.logBasic(
               "Execution finished on a remote pipeline engine with run configuration '"
                   + pipelineRunConfiguration.getName()
