@@ -30,10 +30,12 @@ import org.apache.commons.vfs2.FileObject;
 import org.apache.commons.vfs2.FileSystemException;
 import org.apache.hop.base.AbstractMeta;
 import org.apache.hop.base.BaseHopMeta;
+import org.apache.hop.core.CheckResult;
 import org.apache.hop.core.Const;
 import org.apache.hop.core.ICheckResult;
 import org.apache.hop.core.IProgressMonitor;
 import org.apache.hop.core.NotePadMeta;
+import org.apache.hop.core.ProgressNullMonitorListener;
 import org.apache.hop.core.SqlStatement;
 import org.apache.hop.core.attributes.AttributesUtil;
 import org.apache.hop.core.database.DatabaseMeta;
@@ -78,14 +80,33 @@ import org.w3c.dom.Node;
  */
 public class WorkflowMeta extends AbstractMeta
     implements Cloneable, Comparable<WorkflowMeta>, IXml, IResourceExport, IHasFilename {
-  private static final Class<?> PKG = WorkflowMeta.class;
   public static final String WORKFLOW_EXTENSION = ".hwf";
   public static final String XML_TAG = "workflow";
   public static final int BORDER_INDENT = 20;
+
+  /** A constant specifying the tag value for the XML node of the actions. */
+  public static final String XML_TAG_ACTIONS = "actions";
+
+  /** A constant specifying the tag value for the XML node of the notes. */
+  public static final String XML_TAG_NOTEPADS = "notepads";
+
+  /** A constant specifying the tag value for the XML node of the hops. */
+  public static final String XML_TAG_HOPS = "hops";
+
+  /** A constant specifying the tag value for the XML node of the workflow parameters. */
+  protected static final String XML_TAG_PARAMETERS = "parameters";
+
+  private static final Class<?> PKG = WorkflowMeta.class;
   private static final String CONST_DESCRIPTION = "description";
   private static final String CONST_PARAMETER = "parameter";
   private static final String CONST_SPACE = "        ";
 
+  /**
+   * List of booleans indicating whether or not to remember the size and position of the different
+   * windows...
+   */
+  public boolean[] max = new boolean[1];
+
   @HopMetadataProperty(inline = true)
   protected WorkflowMetaInfo info;
 
@@ -99,33 +120,9 @@ public class WorkflowMeta extends AbstractMeta
   protected String startActionName;
   protected boolean expandingRemoteWorkflow;
 
-  /** Constant = "OK" */
-  public static final String STRING_SPECIAL_OK = "OK";
-
-  /** Constant = "ERROR" */
-  public static final String STRING_SPECIAL_ERROR = "ERROR";
-
   /** The loop cache. */
   protected Map<String, Boolean> loopCache;
 
-  /**
-   * List of booleans indicating whether or not to remember the size and position of the different
-   * windows...
-   */
-  public boolean[] max = new boolean[1];
-
-  /** A constant specifying the tag value for the XML node of the actions. */
-  public static final String XML_TAG_ACTIONS = "actions";
-
-  /** A constant specifying the tag value for the XML node of the notes. */
-  public static final String XML_TAG_NOTEPADS = "notepads";
-
-  /** A constant specifying the tag value for the XML node of the hops. */
-  public static final String XML_TAG_HOPS = "hops";
-
-  /** A constant specifying the tag value for the XML node of the workflow parameters. */
-  protected static final String XML_TAG_PARAMETERS = "parameters";
-
   private List<MissingAction> missingActions;
 
   /** Instantiates a new workflow meta. */
@@ -133,6 +130,62 @@ public class WorkflowMeta extends AbstractMeta
     clear();
   }
 
+  /**
+   * Instantiates a new workflow meta.
+   *
+   * @param fname the fname
+   * @throws HopXmlException the hop xml exception
+   */
+  public WorkflowMeta(String fname) throws HopXmlException {
+    this(null, fname, null);
+  }
+
+  /**
+   * Load the workflow from the XML file specified
+   *
+   * @param variables
+   * @param fname
+   * @param metadataProvider
+   * @throws HopXmlException
+   */
+  public WorkflowMeta(IVariables variables, String fname, IHopMetadataProvider metadataProvider)
+      throws HopXmlException {
+    this.metadataProvider = metadataProvider;
+    loadXml(variables, fname, metadataProvider);
+  }
+
+  /**
+   * Instantiates a new workflow meta.
+   *
+   * @param inputStream the input stream
+   * @param variables
+   * @throws HopXmlException the hop xml exception
+   */
+  public WorkflowMeta(
+      InputStream inputStream, IHopMetadataProvider metadataProvider, IVariables variables)
+      throws HopXmlException {
+    this();
+    this.metadataProvider = metadataProvider;
+    Document doc = XmlHandler.loadXmlFile(inputStream, null, false, false);
+    Node subNode = XmlHandler.getSubNode(doc, WorkflowMeta.XML_TAG);
+    loadXml(subNode, null, metadataProvider, variables);
+  }
+
+  /**
+   * Create a new WorkflowMeta object by loading it from a a DOM node.
+   *
+   * @param workflowNode The node to load from
+   * @param variables
+   * @throws HopXmlException
+   */
+  public WorkflowMeta(
+      Node workflowNode, IHopMetadataProvider metadataProvider, IVariables variables)
+      throws HopXmlException {
+    this();
+    this.metadataProvider = metadataProvider;
+    loadXml(workflowNode, null, metadataProvider, variables);
+  }
+
   /** Clears or reinitializes many of the WorkflowMeta properties. */
   @Override
   public void clear() {
@@ -183,13 +236,13 @@ public class WorkflowMeta extends AbstractMeta
    *       returned.
    * </ol>
    *
-   * @param j1 the first workflow to compare
-   * @param j2 the second workflow to compare
+   * @param workflow1 the first workflow to compare
+   * @param workflow2 the second workflow to compare
    * @return 0 if the two workflows are equal, 1 or -1 depending on the values (see description
    *     above)
    */
-  public int compare(WorkflowMeta j1, WorkflowMeta j2) {
-    return super.compare(j1, j2);
+  public int compare(WorkflowMeta workflow1, WorkflowMeta workflow2) {
+    return super.compare(workflow1, workflow2);
   }
 
   /**
@@ -409,30 +462,6 @@ public class WorkflowMeta extends AbstractMeta
     return XmlFormatter.format(xml.toString());
   }
 
-  /**
-   * Instantiates a new workflow meta.
-   *
-   * @param fname the fname
-   * @throws HopXmlException the hop xml exception
-   */
-  public WorkflowMeta(String fname) throws HopXmlException {
-    this(null, fname, null);
-  }
-
-  /**
-   * Load the workflow from the XML file specified
-   *
-   * @param variables
-   * @param fname
-   * @param metadataProvider
-   * @throws HopXmlException
-   */
-  public WorkflowMeta(IVariables variables, String fname, IHopMetadataProvider metadataProvider)
-      throws HopXmlException {
-    this.metadataProvider = metadataProvider;
-    loadXml(variables, fname, metadataProvider);
-  }
-
   public void loadXml(IVariables variables, String fname, IHopMetadataProvider metadataProvider)
       throws HopXmlException {
     try {
@@ -456,38 +485,6 @@ public class WorkflowMeta extends AbstractMeta
     }
   }
 
-  /**
-   * Instantiates a new workflow meta.
-   *
-   * @param inputStream the input stream
-   * @param variables
-   * @throws HopXmlException the hop xml exception
-   */
-  public WorkflowMeta(
-      InputStream inputStream, IHopMetadataProvider metadataProvider, IVariables variables)
-      throws HopXmlException {
-    this();
-    this.metadataProvider = metadataProvider;
-    Document doc = XmlHandler.loadXmlFile(inputStream, null, false, false);
-    Node subNode = XmlHandler.getSubNode(doc, WorkflowMeta.XML_TAG);
-    loadXml(subNode, null, metadataProvider, variables);
-  }
-
-  /**
-   * Create a new WorkflowMeta object by loading it from a a DOM node.
-   *
-   * @param workflowNode The node to load from
-   * @param variables
-   * @throws HopXmlException
-   */
-  public WorkflowMeta(
-      Node workflowNode, IHopMetadataProvider metadataProvider, IVariables variables)
-      throws HopXmlException {
-    this();
-    this.metadataProvider = metadataProvider;
-    loadXml(workflowNode, null, metadataProvider, variables);
-  }
-
   /**
    * Load a block of XML from an DOM node.
    *
@@ -1068,7 +1065,7 @@ public class WorkflowMeta extends AbstractMeta
    * @param action the jge
    * @return true, if is action used in hops
    */
-  public boolean isEntryUsedInHops(ActionMeta action) {
+  public boolean isActionUsedInHops(ActionMeta action) {
     WorkflowHopMeta from = findWorkflowHopFrom(action);
     WorkflowHopMeta to = findWorkflowHopTo(action);
     return from != null || to != null;
@@ -1080,7 +1077,7 @@ public class WorkflowMeta extends AbstractMeta
    * @param name the name
    * @return the int
    */
-  public int countEntries(String name) {
+  public int countActions(String name) {
     int count = 0;
     int i;
     for (i = 0; i < nrActions(); i++) {
@@ -1614,15 +1611,6 @@ public class WorkflowMeta extends AbstractMeta
     return workflowVersion;
   }
 
-  /**
-   * Gets the status of the workflow.
-   *
-   * @return the status of the workflow
-   */
-  public int getWorkflowStatus() {
-    return workflowStatus;
-  }
-
   /**
    * Set the version of the workflow.
    *
@@ -1632,6 +1620,15 @@ public class WorkflowMeta extends AbstractMeta
     this.workflowVersion = jobVersion;
   }
 
+  /**
+   * Gets the status of the workflow.
+   *
+   * @return the status of the workflow
+   */
+  public int getWorkflowStatus() {
+    return workflowStatus;
+  }
+
   /**
    * Set the status of the workflow.
    *
@@ -1720,7 +1717,7 @@ public class WorkflowMeta extends AbstractMeta
    * own settings.
    *
    * @param remarks List of CheckResult remarks inserted into by each Action
-   * @param onlySelected true if you only want to check the selected workflows
+   * @param onlySelected true if you only want to check the selected actions
    * @param monitor Progress monitor (not presently in use)
    */
   public void checkActions(
@@ -1729,38 +1726,82 @@ public class WorkflowMeta extends AbstractMeta
       IProgressMonitor monitor,
       IVariables variables,
       IHopMetadataProvider metadataProvider) {
-    remarks.clear(); // Empty remarks
-    if (monitor != null) {
+    try {
+      // Start with a clean slate...
+      remarks.clear();
+
+      if (monitor == null) {
+        monitor = new ProgressNullMonitorListener();
+      }
+
+      List<ActionMeta> actions = (onlySelected) ? this.getSelectedActions() : getActions();
+
       monitor.beginTask(
           BaseMessages.getString(PKG, "WorkflowMeta.Monitor.VerifyingThisActionTask.Title"),
-          workflowActions.size() + 2);
-    }
-    boolean stopChecking = false;
-    for (int i = 0; i < workflowActions.size() && !stopChecking; i++) {
-      ActionMeta copy = workflowActions.get(i); // get the action copy
-      if ((!onlySelected) || (onlySelected && copy.isSelected())) {
-        IAction action = copy.getAction();
-        if (action != null) {
-          if (monitor != null) {
-            monitor.subTask(
+          actions.size());
+
+      // Check for the presence of a start action
+      if (findStart() == null) {
+        remarks.add(
+            new CheckResult(
+                ICheckResult.TYPE_RESULT_ERROR,
                 BaseMessages.getString(
-                    PKG, "WorkflowMeta.Monitor.VerifyingAction.Title", action.getName()));
+                    PKG, "WorkflowMeta.CheckResult.StartActionIsMissing.Description"),
+                null));
+      }
+
+      int worked = 1;
+      for (ActionMeta actionMeta : actions) {
+        if (monitor.isCanceled()) {
+          break;
+        }
+
+        IAction action = actionMeta.getAction();
+        if (action != null) {
+          monitor.subTask(
+              BaseMessages.getString(
+                  PKG, "WorkflowMeta.Monitor.VerifyingAction.Title", action.getName()));
+
+          // Check missing action plugin
+          if (action instanceof MissingAction missingAction) {
+            remarks.add(
+                new CheckResult(
+                    ICheckResult.TYPE_RESULT_ERROR,
+                    BaseMessages.getString(
+                        PKG,
+                        "WorkflowMeta.CheckResult.ActionPluginNotFound.Description",
+                        missingAction.getMissingPluginId()),
+                    action));
           }
-          action.check(remarks, this, variables, metadataProvider);
-          if (monitor != null) {
-            monitor.worked(1); // progress bar...
-            if (monitor.isCanceled()) {
-              stopChecking = true;
-            }
+
+          // Check deprecated action plugin
+          if (actionMeta.isDeprecated()) {
+            remarks.add(
+                new CheckResult(
+                    ICheckResult.TYPE_RESULT_WARNING,
+                    BaseMessages.getString(
+                        PKG, "WorkflowMeta.CheckResult.DeprecatedActionPlugin.Description"),
+                    action));
+          }
+
+          if (isActionUsedInHops(actionMeta) || getActions().size() == 1) {
+            action.check(remarks, this, variables, metadataProvider);
+          } else {
+            remarks.add(
+                new CheckResult(
+                    ICheckResult.TYPE_RESULT_WARNING,
+                    BaseMessages.getString(
+                        PKG, "WorkflowMeta.CheckResult.ActionIsNotUsed.Description"),
+                    action));
           }
         }
+        // Progress bar...
+        monitor.worked(worked++);
       }
-      if (monitor != null) {
-        monitor.worked(1);
-      }
-    }
-    if (monitor != null) {
+
       monitor.done();
+    } catch (Exception e) {
+      throw new RuntimeException("Error checking workflow", e);
     }
   }
 
@@ -2101,16 +2142,6 @@ public class WorkflowMeta extends AbstractMeta
     info.setCreatedDate(createdDate);
   }
 
-  /**
-   * Sets the user by whom the pipeline was created.
-   *
-   * @param createdUser The user to set.
-   */
-  @Override
-  public void setCreatedUser(String createdUser) {
-    info.setCreatedUser(createdUser);
-  }
-
   /**
    * Gets the user by whom the pipeline was created.
    *
@@ -2122,13 +2153,13 @@ public class WorkflowMeta extends AbstractMeta
   }
 
   /**
-   * Sets the date the pipeline was modified.
+   * Sets the user by whom the pipeline was created.
    *
-   * @param modifiedDate The modified date to set.
+   * @param createdUser The user to set.
    */
   @Override
-  public void setModifiedDate(Date modifiedDate) {
-    info.setModifiedDate(modifiedDate);
+  public void setCreatedUser(String createdUser) {
+    info.setCreatedUser(createdUser);
   }
 
   /**
@@ -2142,13 +2173,13 @@ public class WorkflowMeta extends AbstractMeta
   }
 
   /**
-   * Sets the user who last modified the pipeline.
+   * Sets the date the pipeline was modified.
    *
-   * @param modifiedUser The user name to set.
+   * @param modifiedDate The modified date to set.
    */
   @Override
-  public void setModifiedUser(String modifiedUser) {
-    info.setModifiedUser(modifiedUser);
+  public void setModifiedDate(Date modifiedDate) {
+    info.setModifiedDate(modifiedDate);
   }
 
   /**
@@ -2160,4 +2191,14 @@ public class WorkflowMeta extends AbstractMeta
   public String getModifiedUser() {
     return info.getModifiedUser();
   }
+
+  /**
+   * Sets the user who last modified the pipeline.
+   *
+   * @param modifiedUser The user name to set.
+   */
+  @Override
+  public void setModifiedUser(String modifiedUser) {
+    info.setModifiedUser(modifiedUser);
+  }
 }
