@@ -58,7 +58,7 @@ import org.apache.hop.pipeline.engine.IPipelineEngine;
 import org.apache.hop.pipeline.engines.remote.RemotePipelineEngine;
 import org.apache.hop.resource.ResourceUtil;
 import org.apache.hop.resource.TopLevelResource;
-import org.apache.hop.server.HopServer;
+import org.apache.hop.server.HopServerMeta;
 import org.apache.hop.workflow.ActionResult;
 import org.apache.hop.workflow.IActionListener;
 import org.apache.hop.workflow.IDelegationListener;
@@ -82,7 +82,7 @@ import org.apache.hop.www.WebResult;
     description = "Executes your workflow on a remote hop server")
 public class RemoteWorkflowEngine extends Variables implements IWorkflowEngine<WorkflowMeta> {
 
-  private static final Class<?> PKG = Workflow.class; // For Translator
+  private static final Class<?> PKG = Workflow.class;
 
   /**
    * Constant specifying a filename containing XML to inject into a ZIP file created during resource
@@ -103,7 +103,7 @@ public class RemoteWorkflowEngine extends Variables implements IWorkflowEngine<W
   protected LogLevel logLevel;
   protected long serverPollDelay;
   protected long serverPollInterval;
-  protected HopServer hopServer;
+  protected HopServerMeta hopServer;
   protected String containerId;
   protected int lastLogLineNr;
   protected boolean stopped;
@@ -237,6 +237,12 @@ public class RemoteWorkflowEngine extends Variables implements IWorkflowEngine<W
       if (StringUtils.isEmpty(remoteRunConfigurationName)) {
         throw new HopException("No run configuration was specified to the remote workflow with");
       }
+      if (workflowRunConfiguration.getName().equals(remoteRunConfigurationName)) {
+        throw new HopException(
+            "The remote workflow run configuration refers to itself '"
+                + remoteRunConfigurationName
+                + "'");
+      }
       if (metadataProvider == null) {
         throw new HopException(
             "The remote workflow engine didn't receive a metadata to load hop server '"
@@ -254,7 +260,7 @@ public class RemoteWorkflowEngine extends Variables implements IWorkflowEngine<W
       serverPollInterval =
           Const.toLong(resolve(remoteWorkflowRunConfiguration.getServerPollInterval()), 2000L);
 
-      hopServer = metadataProvider.getSerializer(HopServer.class).load(hopServerName);
+      hopServer = metadataProvider.getSerializer(HopServerMeta.class).load(hopServerName);
       if (hopServer == null) {
         throw new HopException("Hop server '" + hopServerName + "' could not be found");
       }
@@ -462,6 +468,10 @@ public class RemoteWorkflowEngine extends Variables implements IWorkflowEngine<W
     }
   }
 
+  /**
+   * @deprecated
+   * @param finishedListener
+   */
   @Override
   @Deprecated(since = "2.9", forRemoval = true)
   public void addWorkflowFinishedListener(
@@ -471,6 +481,10 @@ public class RemoteWorkflowEngine extends Variables implements IWorkflowEngine<W
     }
   }
 
+  /**
+   * @deprecated
+   * @throws HopException
+   */
   @Override
   @Deprecated(since = "2.9", forRemoval = true)
   public void fireWorkflowFinishListeners() throws HopException {
@@ -482,6 +496,10 @@ public class RemoteWorkflowEngine extends Variables implements IWorkflowEngine<W
     }
   }
 
+  /**
+   * @deprecated
+   * @param finishedListener
+   */
   @Override
   @Deprecated(since = "2.9", forRemoval = true)
   public void addWorkflowStartedListener(
@@ -491,6 +509,10 @@ public class RemoteWorkflowEngine extends Variables implements IWorkflowEngine<W
     }
   }
 
+  /**
+   * @deprecated
+   * @throws HopException
+   */
   @Override
   @Deprecated(since = "2.9", forRemoval = true)
   public void fireWorkflowStartedListeners() throws HopException {
@@ -950,14 +972,14 @@ public class RemoteWorkflowEngine extends Variables implements IWorkflowEngine<W
    *
    * @return value of hopServer
    */
-  public HopServer getHopServer() {
+  public HopServerMeta getHopServer() {
     return hopServer;
   }
 
   /**
    * @param hopServer The hopServer to set
    */
-  public void setHopServer(HopServer hopServer) {
+  public void setHopServer(HopServerMeta hopServer) {
     this.hopServer = hopServer;
   }
 
@@ -1158,8 +1180,7 @@ public class RemoteWorkflowEngine extends Variables implements IWorkflowEngine<W
   }
 
   /**
-   * Gets workflowFinishedListeners
-   *
+   * @deprecated Gets workflowFinishedListeners
    * @return value of workflowFinishedListeners
    */
   @Override
@@ -1170,6 +1191,7 @@ public class RemoteWorkflowEngine extends Variables implements IWorkflowEngine<W
   }
 
   /**
+   * @deprecated
    * @param workflowFinishedListeners The workflowFinishedListeners to set
    */
   @Deprecated(since = "2.9", forRemoval = true)
@@ -1179,8 +1201,7 @@ public class RemoteWorkflowEngine extends Variables implements IWorkflowEngine<W
   }
 
   /**
-   * Gets workflowStartedListeners
-   *
+   * @deprecated Gets workflowStartedListeners
    * @return value of workflowStartedListeners
    */
   @Override
@@ -1191,6 +1212,7 @@ public class RemoteWorkflowEngine extends Variables implements IWorkflowEngine<W
   }
 
   /**
+   * @deprecated
    * @param workflowStartedListeners The workflowStartedListeners to set
    */
   @Deprecated(since = "2.9", forRemoval = true)
