@@ -38,7 +38,7 @@ public class GetPipelineImageServlet extends BaseHttpServlet implements IHopServ
   private static final long serialVersionUID = -4365372274638005929L;
   public static final float ZOOM_FACTOR = 1.0f;
 
-  private static final Class<?> PKG = GetPipelineImageServlet.class; // For Translator
+  private static final Class<?> PKG = GetPipelineImageServlet.class;
 
   public static final String CONTEXT_PATH = "/hop/pipelineImage";
 
