@@ -17,8 +17,8 @@
 
 package org.apache.hop.www;
 
+import jakarta.xml.bind.annotation.XmlRootElement;
 import java.util.Comparator;
-import javax.xml.bind.annotation.XmlRootElement;
 
 /** A carte object entry in the pipeline or workflow maps */
 @XmlRootElement
