@@ -17,7 +17,7 @@
 
 package org.apache.hop.www.jaxrs;
 
-import javax.xml.bind.annotation.XmlRootElement;
+import jakarta.xml.bind.annotation.XmlRootElement;
 
 @XmlRootElement
 public class NVPair {
