@@ -44,7 +44,9 @@ import org.apache.hop.www.HopServerSingleton;
 @Path("/carte/workflow")
 public class WorkflowResource {
 
-  public WorkflowResource() {}
+  public WorkflowResource() {
+    // Do nothing
+  }
 
   @GET
   @Path("/log/{id : .+}")
@@ -59,11 +61,10 @@ public class WorkflowResource {
   public String getWorkflowLog(@PathParam("id") String id, @PathParam("logStart") int startLineNr) {
     int lastLineNr = HopLogStore.getLastBufferLineNr();
     IWorkflowEngine<WorkflowMeta> workflow = HopServerResource.getWorkflow(id);
-    String logText =
-        HopLogStore.getAppender()
-            .getBuffer(workflow.getLogChannel().getLogChannelId(), false, startLineNr, lastLineNr)
-            .toString();
-    return logText;
+
+    return HopLogStore.getAppender()
+        .getBuffer(workflow.getLogChannel().getLogChannelId(), false, startLineNr, lastLineNr)
+        .toString();
   }
 
   @GET
@@ -139,7 +140,7 @@ public class WorkflowResource {
     // Simply start the workflow in the background in a new thread.
     // This will allow us to work asynchronously
     //
-    new Thread(() -> finalWorkflow.startExecution()).start();
+    new Thread(finalWorkflow::startExecution).start();
 
     return getWorkflowStatus(id);
   }
