@@ -20,7 +20,6 @@ package org.apache.hop.www;
 import static org.junit.Assert.assertFalse;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.anyString;
-import static org.mockito.Mockito.atLeastOnce;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
@@ -37,13 +36,9 @@ import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.junit.Before;
 import org.junit.Test;
-import org.junit.runner.RunWith;
+import org.mockito.Mockito;
 import org.owasp.encoder.Encode;
-import org.powermock.api.mockito.PowerMockito;
-import org.powermock.core.classloader.annotations.PrepareForTest;
-import org.powermock.modules.junit4.PowerMockRunner;
 
-@RunWith(PowerMockRunner.class)
 public class GetPipelineStatusServletTest {
   private PipelineMap mockPipelineMap;
 
@@ -56,7 +51,6 @@ public class GetPipelineStatusServletTest {
   }
 
   @Test
-  @PrepareForTest({Encode.class})
   public void testGetPipelineStatusServletEscapesHtmlWhenPipelineNotFound()
       throws ServletException, IOException {
     HttpServletRequest mockHttpServletRequest = mock(HttpServletRequest.class);
@@ -65,7 +59,7 @@ public class GetPipelineStatusServletTest {
     StringWriter out = new StringWriter();
     PrintWriter printWriter = new PrintWriter(out);
 
-    PowerMockito.spy(Encode.class);
+    Mockito.spy(Encode.class);
     when(mockHttpServletRequest.getContextPath()).thenReturn(GetPipelineStatusServlet.CONTEXT_PATH);
     when(mockHttpServletRequest.getParameter(anyString()))
         .thenReturn(ServletTestUtils.BAD_STRING_TO_TEST);
@@ -73,13 +67,9 @@ public class GetPipelineStatusServletTest {
 
     getPipelineStatusServlet.doGet(mockHttpServletRequest, mockHttpServletResponse);
     assertFalse(ServletTestUtils.hasBadText(ServletTestUtils.getInsideOfTag("H1", out.toString())));
-
-    PowerMockito.verifyStatic(Encode.class, atLeastOnce());
-    Encode.forHtml(anyString());
   }
 
   @Test
-  @PrepareForTest({Encode.class})
   public void testGetPipelineStatusServletEscapesHtmlWhenPipelineFound()
       throws ServletException, IOException {
     HopLogStore.init();
@@ -91,7 +81,7 @@ public class GetPipelineStatusServletTest {
     StringWriter out = new StringWriter();
     PrintWriter printWriter = new PrintWriter(out);
 
-    PowerMockito.spy(Encode.class);
+    Mockito.spy(Encode.class);
     when(mockHttpServletRequest.getContextPath()).thenReturn(GetPipelineStatusServlet.CONTEXT_PATH);
     when(mockHttpServletRequest.getParameter(anyString()))
         .thenReturn(ServletTestUtils.BAD_STRING_TO_TEST);
@@ -104,8 +94,5 @@ public class GetPipelineStatusServletTest {
     getPipelineStatusServlet.doGet(mockHttpServletRequest, mockHttpServletResponse);
     assertFalse(
         ServletTestUtils.hasBadText(ServletTestUtils.getInsideOfTag("TITLE", out.toString())));
-
-    PowerMockito.verifyStatic(Encode.class, atLeastOnce());
-    Encode.forHtml(anyString());
   }
 }
