@@ -269,7 +269,7 @@ public class ActionPGPDecryptFilesDialog extends ActionDialog {
         SWT.Selection,
         e ->
             BaseDialog.presentFileDialog(
-                shell, wGpgExe, variables, new String[] {"*"}, FILETYPES, true));
+                shell, wGpgExe, variables, new String[] {"*"}, FILETYPES, false));
 
     wGpgExe = new TextVar(variables, wSettings, SWT.SINGLE | SWT.LEFT | SWT.BORDER);
     wGpgExe.setToolTipText(BaseMessages.getString(PKG, "ActionPGPDecryptFiles.GpgExe.Tooltip"));
@@ -407,7 +407,7 @@ public class ActionPGPDecryptFilesDialog extends ActionDialog {
         SWT.Selection,
         e ->
             BaseDialog.presentFileDialog(
-                shell, wSourceFileFolder, variables, new String[] {"*"}, FILETYPES, true));
+                shell, wSourceFileFolder, variables, new String[] {"*"}, FILETYPES, false));
 
     // Destination
     wlDestinationFileFolder = new Label(wGeneralComp, SWT.RIGHT);
@@ -459,7 +459,7 @@ public class ActionPGPDecryptFilesDialog extends ActionDialog {
         SWT.Selection,
         e ->
             BaseDialog.presentFileDialog(
-                shell, wDestinationFileFolder, variables, new String[] {"*"}, FILETYPES, true));
+                shell, wDestinationFileFolder, variables, new String[] {"*"}, FILETYPES, false));
 
     // Wildcard
     wlWildcard = new Label(wGeneralComp, SWT.RIGHT);
